@@ -28,7 +28,7 @@ from django.test import TestCase
 from django.test.client import RequestFactory, Client
 from django.utils.translation import override, gettext as _, gettext_lazy
 from rest_framework.exceptions import NotAuthenticated
-from jutil.admin import admin_log, admin_obj_url, admin_obj_link, ModelAdminBase, AdminLogEntryMixin
+from jutil.admin import admin_log, admin_obj_url, admin_obj_link, ModelAdminBase, AdminLogEntryMixin, get_admin_log
 from jutil.auth import AuthUserMixin, get_auth_user, get_auth_user_or_none
 from jutil.command import get_date_range_by_name, add_date_range_arguments, parse_date_range_arguments, get_command_by_name, get_command_name
 from jutil.email import make_email_recipient_list
@@ -40,6 +40,7 @@ from jutil.model import (
     get_object_or_none,
     wait_object_or_none,
 )
+from jutil.redis_helpers import redis_set_json, redis_get_json, redis_get_bytes, redis_set_bytes, redis_get_json_or_none, redis_get_bytes_or_none, redis_delete
 from jutil.request import get_ip_info
 from jutil.responses import CsvResponse
 from jutil.testing import TestSetupMixin
@@ -800,6 +801,7 @@ class Tests(TestCase, TestSetupMixin):
         admin_log([obj], "Hello, world")
         admin_log([obj], "Hello, world", user=self.user, ip="127.0.0.1")
         admin_log(obj, "Hello, world", user=self.user, ip="127.0.0.1")
+        self.assertGreaterEqual(get_admin_log(obj).filter(change_message__contains="Hello, world").count(), 3)
         e = LogEntry.objects.all().filter(object_id=obj.id).last()
         self.assertIsNotNone(e)
         assert isinstance(e, LogEntry)
@@ -1302,6 +1304,20 @@ class Tests(TestCase, TestSetupMixin):
             self.assertTrue(isinstance(cls, BaseCommand))
             self.assertEqual(get_command_name(cls), cmd_name)
 
+    def test_redis_helpers(self):
+        for k in ["jani", "jani2", "jani3", "jani4"]:
+            redis_delete(k)
+        self.assertEqual(redis_get_json_or_none("jani2"), None)
+        self.assertEqual(redis_get_bytes_or_none("jani"), None)
+        redis_set_json("jani", {"a": 1})
+        redis_set_json("jani2", "testing")
+        redis_set_bytes("jani3", b'{"a":2}')
+        self.assertDictEqual(redis_get_json("jani"), {"a": 1})
+        self.assertEqual(redis_get_json("jani2"), "testing")
+        self.assertEqual(redis_get_bytes("jani"), b'{"a": 1}')
+        self.assertEqual(redis_get_bytes("jani2"), b'"testing"')
+        self.assertDictEqual(redis_get_json("jani3"), {"a": 2})
+
 
 dummy_admin_func_a.short_description = "A"  # type: ignore
 dummy_admin_func_b.short_description = "B"  # type: ignore
